import { LiveAnnouncer } from '@angular/cdk/a11y';
import { HttpClient } from '@angular/common/http';
import { Component, OnInit, ViewChild } from '@angular/core';
import { FormBuilder } from '@angular/forms';
import { MatPaginator } from '@angular/material/paginator';
import { MatSort, Sort } from '@angular/material/sort';
import { MatTableDataSource } from '@angular/material/table';
import { ActivatedRoute, Router } from '@angular/router';
import { Gruppe } from '../Gruppe';
import { GruppeService } from '../services/gruppe.service';

@Component({
  selector: 'app-gruppen',
  templateUrl: './gruppen.component.html',
  styleUrls: ['./gruppen.component.css']
})
export class GruppenComponent implements OnInit {

  public gruppen: any;
  public selection: any;
  public dataSource: any;
  displayedColumns: any = ["groupid", "groupname", "date_started", "date_end", "Anmerkung"];

  constructor(private _liveAnnouncer: LiveAnnouncer,
    private formbuilder: FormBuilder,
    private router: Router,
    private activatedRoute: ActivatedRoute,
    private http: HttpClient,
    private grpService: GruppeService
    ) { }

    @ViewChild('paginator') paginator: MatPaginator;
    @ViewChild(MatSort) sort: MatSort;
    
  ngOnInit(): void {
    this.grpService.getGruppen().subscribe (
      (
        result: any) => {
        console.log(result);
        this.gruppen = result.data;
        this.dataSource = new MatTableDataSource(this.gruppen)
        this.dataSource.paginator = this.paginator;
        this.dataSource.sort = this.sort;
      })
  }

  applyFilter(event: Event) {
    const filterValue = (event.target as HTMLInputElement).value;
    this.dataSource.filter = filterValue.trim().toLowerCase();
    console.log("Filter: " + this.dataSource.filter);
  }

  /** Announce the change in sort state for assistive technology. */
  announceSortChange(sortState: Sort) {
    // This example uses English messages. If your application supports
    // multiple language, you would internationalize these strings.
    // Furthermore, you can customize the message to add additional
    // details about the values being sorted.
    if (sortState.direction) {
      this._liveAnnouncer.announce(`Sorted ${sortState.direction}ending`);
    } else {
      this._liveAnnouncer.announce('Sorting cleared');
    }
  }

  ngAfterViewInit() {
    if(this.dataSource != undefined) {
      this.dataSource.paginator = this.paginator;
      this.dataSource.sort = this.sort;
      console.log(this.dataSource);
    }
    else
      console.log("DataSource undefined in AfterViewInit");
  }

  onclick(aktuell: Gruppe) {

  }
}
